@@ -32,8 +32,8 @@ enum hypervisors {
 	HYPER_KVM,
 	HYPER_MSHV,
 	HYPER_VMWARE,
+	// Must always be last
 	HYPER_OTHER,
-	HYPER_LAST /* for loop - must be last*/
 };
 
 const char *hypervisor_ids[] = {
@@ -157,7 +157,7 @@ int detect_hypervisor(int *hypervisor) {
 		*hypervisor = HYPER_OTHER;
 
 		if (*sig.text) {
-			for (int id = HYPER_NONE + 1; id < HYPER_LAST; id++) {
+			for (int id = HYPER_NONE + 1; id < HYPER_OTHER; id++) {
 				if (strcmp(hypervisor_ids[id], sig.text) == 0) {
 					*hypervisor = id;
 					break;
