@@ -44,13 +44,16 @@ INVALID_ID_STRINGS = (
 	"EVAL",
 	"Not Applicable",
 	"None", "empty",
-	"Serial", "System Serial Number",
+	"Serial", "System Serial Number", "SSN",
 	"XXXXX",
 	"01010101-0101-0101-0101-010101010101",
 	"00020003-0004-0005-0006-000700080009",
 	"03000200-0400-0500-0006-000700080009",
 	"11111111-1111-1111-1111-111111111111",
 	"0000000", "00000000",
+
+	# Jetway gives all systems the same product UUID
+	"3b903780-4f79-1018-816e-aeb2724778a7",
 )
 
 INVALID_ID_STRINGS_EXACT_MATCH = (
@@ -269,7 +272,9 @@ class System(object, metaclass=Singleton):
 		if not ids:
 			root_disk_serial = self.root_disk_serial
 			if root_disk_serial and not root_disk_serial.startswith("QM000"):
-				ids.append(root_disk_serial)
+				# Skip any invalid IDs
+				if not root_disk_serial in INVALID_ID_STRINGS:
+					ids.append(root_disk_serial)
 
 		# As last resort, we use the UUID from pakfire.
 		if not ids:
